from scraipe.scrapers.default_scraper import DefaultScraper
from scraipe.scrapers.news_scraper import NewsScraper
from scraipe.scrapers.telegram_scraper import TelegramScraper
from scraipe.scrapers.multi_scraper import MultiScraper